import { FURO_SUBGRAPH_URL } from 'sushi/config/subgraph';
import { addChainId } from '../../../lib/modifiers/add-chain-id';
import { convertIdToMultichainId } from '../../../lib/modifiers/convert-id-to-multichain-id';
import { copyIdToAddress } from '../../../lib/modifiers/copy-id-to-address';
import { requestPaged } from '../../../lib/request-paged';
import { graphql } from '../graphql';
export const FuroTokensQuery = graphql(`
  query Tokens($first: Int = 1000, $skip: Int = 0, $block: Block_height, $orderBy: Token_orderBy, $orderDirection: OrderDirection, $where: Token_filter) {
    tokens(first: $first, skip: $skip, block: $block, orderBy: $orderBy, orderDirection: $orderDirection, where: $where) {
      id
      decimals
      liquidityShares
      symbol
      name
      rebase {
        base
        elastic
      }
    }
  }
`);
export async function getFuroTokens({ chainId, ...variables }, options) {
    const url = `https://${FURO_SUBGRAPH_URL[chainId]}`;
    const result = await requestPaged({
        chainId,
        url,
        query: FuroTokensQuery,
        variables,
        options,
    });
    return result.tokens.map((token) => convertIdToMultichainId(copyIdToAddress(addChainId(chainId, token))));
}
