import { request } from '../../../lib/request';
import { graphql } from '../graphql';
import { STRAPI_GRAPHQL_URL } from '../../../subgraphs/strapi/constants';
import { ImageFieldsFragment } from '../../../subgraphs/strapi/fragments/image-fields';
import { transformImage } from '../../../subgraphs/strapi/transforms/transform-image';
export const StrapiProductsQuery = graphql(`query Products {
    products {
      data {
        id
        attributes {
          name
          description
          longName
          slug
          url
          relevantArticleIds
          shareImage {
            data {
              ...ImageFields
            }
          }
        }
      }
    }
  }`, [ImageFieldsFragment]);
export async function getProducts(_variables = {}, options) {
    const variables = _variables;
    const result = await request({
        url: STRAPI_GRAPHQL_URL,
        document: StrapiProductsQuery,
        variables,
    }, options);
    if (!result.products) {
        throw new Error('Failed to fetch products');
    }
    return result.products.data.map((product) => ({
        id: product.id,
        name: product.attributes.name,
        description: product.attributes.description,
        longName: product.attributes.longName,
        slug: product.attributes.slug,
        url: product.attributes.url,
        relevantArticleIds: product.attributes.relevantArticleIds,
        shareImage: product.attributes.shareImage.data
            ? transformImage(product.attributes.shareImage.data)
            : null,
    }));
}
