import { SUSHISWAP_V2_SUBGRAPH_URL } from 'sushi/config/subgraph';
import { requestPaged } from '../../../lib/request-paged';
import { graphql } from '../graphql';
export const SushiV2DayDatasQuery = graphql(`
  query DayDatas($first: Int = 1000, $skip: Int = 0, $block: Block_height, $orderBy: UniswapDayData_orderBy, $orderDirection: OrderDirection, $where: UniswapDayData_filter) {
    uniswapDayDatas(first: $first, skip: $skip, block: $block, orderBy: $orderBy, orderDirection: $orderDirection, where: $where) {
      id
      date
      dailyVolumeUSD
      dailyVolumeUntracked
      totalLiquidityUSD
      txCount
    }
  }
`);
export async function getSushiV2DayDatas({ chainId, ...variables }, options) {
    const url = `https://${SUSHISWAP_V2_SUBGRAPH_URL[chainId]}`;
    const result = await requestPaged({
        chainId,
        url,
        query: SushiV2DayDatasQuery,
        variables,
        options,
    });
    return result.uniswapDayDatas.map((dayData) => ({
        id: dayData.id,
        date: dayData.date,
        volumeUSD: Number(dayData.dailyVolumeUSD),
        volumeUSDUntracked: Number(dayData.dailyVolumeUntracked),
        liquidityUSD: Number(dayData.totalLiquidityUSD),
        txCount: Number(dayData.txCount),
        feesUSD: Number(dayData.totalLiquidityUSD) * 0.003,
    }));
}
