import { SUSHISWAP_V2_SUBGRAPH_URL } from 'sushi/config/subgraph';
import { FetchError } from '../../../lib/fetch-error';
import { addChainId } from '../../../lib/modifiers/add-chain-id';
import { convertIdToMultichainId } from '../../../lib/modifiers/convert-id-to-multichain-id';
import { copyIdToAddress } from '../../../lib/modifiers/copy-id-to-address';
import { request } from '../../../lib/request';
import { graphql } from '../graphql';
export const SushiV2FactoriesQuery = graphql(`
  query Factories {
    uniswapFactories(first: 1) {
      id
      totalLiquidityUSD
      untrackedVolumeUSD
      totalVolumeUSD
      poolCount: pairCount
    }
  }
`);
export async function getSushiV2Factory({ chainId, ...variables }, options) {
    const url = `https://${SUSHISWAP_V2_SUBGRAPH_URL[chainId]}`;
    const result = await request({
        url,
        document: SushiV2FactoriesQuery,
        variables,
    }, options);
    if (result.uniswapFactories[0]) {
        return convertIdToMultichainId(copyIdToAddress(addChainId(chainId, result.uniswapFactories[0])));
    }
    throw new FetchError(chainId, 'Failed to fetch factory');
}
