import { SUSHISWAP_V2_SUBGRAPH_URL } from 'sushi/config/subgraph';
import { FetchError } from '../../../lib/fetch-error';
import { requestPaged } from '../../../lib/request-paged';
import { transformPoolV2ToBase } from '../../../subgraphs/sushi-v2/transforms/pool-v2-to-base';
import { PoolFieldsFragment } from '../fragments/pool-fields';
import { graphql } from '../graphql';
export const SushiV2PoolsQuery = graphql(`
  query Pools($first: Int = 1000, $skip: Int = 0, $block: Block_height, $orderBy: Pair_orderBy, $orderDirection: OrderDirection, $where: Pair_filter) {
    pairs(first: $first, skip: $skip, block: $block, orderBy: $orderBy, orderDirection: $orderDirection, where: $where) {
      ...PoolFields
    }
  }
`, [PoolFieldsFragment]);
export async function getSushiV2Pools({ chainId, ...variables }, options) {
    const url = `https://${SUSHISWAP_V2_SUBGRAPH_URL[chainId]}`;
    const result = await requestPaged({
        chainId,
        url,
        query: SushiV2PoolsQuery,
        variables,
        options,
    });
    if (result) {
        return result.pairs.map((pool) => transformPoolV2ToBase(pool, chainId));
    }
    throw new FetchError(chainId, 'Failed to fetch pools');
}
